"bmaModelParameters" <-
function(fit, ...) 
UseMethod("bmaModelParameters")

